@@ -5,6 +5,7 @@ from ._init_methods import initialize_project
 from ._init_methods import hello
 from ._init_methods import create_config_file
 from ._nordstrom_rock_it import rock_it
+from ._init_methods import topdemandeditem
 
 # s3 functions
 from ._s3 import s3_to_redshift
@@ -48,7 +49,7 @@ from ._secret import _get_secret
 # knowledge repo functions
 from ._knowledge_repo_utils import render_post
 
-__version__ = '2.1.2.2'
+__version__ = '2.1.3'
 
 __all__ = ["_datasource", "_init_methods", "_knowledge_repo_utils",
            "_nordstrom_rock_it", "_redshift_utils", "_s3", "_athena"
